@@ -46,9 +46,9 @@ class cmnConfig:
         -----
             設定ファイル名を変更したい場合はcmnConfigを継承して当メソッドをオーバーライドする
         """
-        return 'config.ini'
+        return 'LibHanger.ini'
     
-    def getConfig(self, scriptPath: str, configFileDirName: str = ''):
+    def getConfig(self, scriptPath: str, configFileDir: str = ''):
 
         """ 
         設定ファイルを読み込む 
@@ -59,17 +59,21 @@ class cmnConfig:
             共通設定クラス
         scriptPath : str
             スクリプトファイルパス
-        configFileDirName : str
-            config.iniがあるディレクトリ名
+        configFileDir : str
+            iniファイルがあるディレクトリ(相対パス)
         
         """
         
         # configparser宣言
         config_ini = configparser.ConfigParser()
 
+        # スクリプトファイルの場所から見たiniファイル相対パス取得
+        iniFileDirPath = self.getConfigFileName() \
+            if configFileDir == '' else os.path.join(configFileDir, self.getConfigFileName())
+        # スクリプトファイルの絶対パス取得
+        iniScriptPathAbs = pathlib.Path(os.path.abspath(os.path.dirname(scriptPath)))
         # iniファイルパス取得
-        iniDirPath = pathlib.Path(os.path.abspath(os.path.dirname(scriptPath)))
-        iniFilePath = os.path.join(iniDirPath, configFileDirName, self.getConfigFileName())
+        iniFilePath = os.path.join(iniScriptPathAbs, iniFileDirPath)
 
         # iniファイル存在確認
         if (not os.path.exists(iniFilePath)): 
@@ -82,16 +86,30 @@ class cmnConfig:
 
         # iniファイル読込
         config_ini.read(iniFilePath, encoding='utf-8')
-
-        # 各設定値をインスタンス変数にセット
-        self.setConfigValue('LogFileName',config_ini,'DEFAULT','LOGFILE_NAME', str)
-        self.setConfigValue('LogFolderName',config_ini,'DEFAULT','LOGFOLDER_NAME', str)
-        self.setConfigValue('LogFormat',config_ini,'DEFAULT','LOGFORMAT', str)
-        self.setConfigValue('LogLevel',config_ini,'DEFAULT','LOGLEVEL', int)
         
         # 読込内容をインスタンス変数に設定する
         self.config_ini = config_ini
 
+        # 各設定値をインスタンス変数にセット
+        self.setInstanceMemberValues()
+        
+    def setInstanceMemberValues(self):
+        
+        """ 
+        インスタンス変数に読み取った設定値をセットする
+        
+        Parameters
+        ----------
+        config_ini : list
+            iniファイル読込内容List
+        
+        """
+        
+        self.setConfigValue('LogFileName', self.config_ini,'DEFAULT','LOGFILE_NAME', str)
+        self.setConfigValue('LogFolderName', self.config_ini,'DEFAULT','LOGFOLDER_NAME', str)
+        self.setConfigValue('LogFormat', self.config_ini,'DEFAULT','LOGFORMAT', str)
+        self.setConfigValue('LogLevel', self.config_ini,'DEFAULT','LOGLEVEL', int)
+
     def setConfigValue(self, 
                        insVariableName: str, 
                        config_ini: list, 
@@ -127,8 +145,9 @@ class cmnConfig:
                 例:self.STRUCT.Test1の場合 ⇒ insVariableNameに"STRUCT.Test1"を指定する 
         
         """
-
-        if config_ini[section].get(key) != None:
+        
+        keyExists = section in config_ini
+        if keyExists and config_ini[section].get(key) != None:
             
             if dataType is str:
                 self.rsetattr(self, insVariableName, config_ini[section][key])
